%define	lib_major	1
%define	lib_name	%mklibname %{name}%{lib_major}
%define	devel_name	%mklibname %{name} -d
%define	static_name	%mklibname %{name} -d -s

%define libminizip	%mklibname minizip %{lib_major}
%define minizip_devel	%mklibname minizip -d

%bcond_without minizip
%bcond_without dietlibc

Summary:	The zlib compression and decompression library
Name:		zlib
Version:	1.2.13
%define subrel 1
Release:	%mkrel 1
Group:		System/Libraries
License:	BSD
URL:		http://www.zlib.net/
Source0:	http://www.zlib.net/%{name}-%{version}.tar.gz
Patch0:		CVE-2023-45853.patch

BuildRequires:	util-linux
%if %{with dietlibc}
BuildRequires:	dietlibc-devel
%endif
%if %{with minizip}
BuildRequires:	pkgconfig(zlib)
%endif

%description
The zlib compression library provides in-memory compression and
decompression functions, including integrity checks of the uncompressed
data.  This version of the library supports only one compression method
(deflation), but other algorithms may be added later, which will have
the same stream interface.  The zlib library is used by many different
system programs.

%package -n	%{lib_name}
Summary:	The zlib compression and decompression library
Group:		System/Libraries
Requires(pre):	filesystem >= 2.1.9-18
Provides:	libz = %{version}-%{release}
Provides:	libz1 = %{version}-%{release}
Provides:	%{name} = %{version}-%{release}
Conflicts:      libzlib1 < 1.2.9
Conflicts:      lib64zlib1 < 1.2.9

%description -n	%{lib_name}
The zlib compression library provides in-memory compression and
decompression functions, including integrity checks of the uncompressed
data.  This version of the library supports only one compression method
(deflation), but other algorithms may be added later, which will have
the same stream interface.  The zlib library is used by many different
system programs.

%package -n	%{devel_name}
Summary:	Header files and libraries for developing apps which will use zlib
Group:		Development/C
Requires:	%{lib_name} = %{version}-%{release}
Provides:	libz-devel = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n	%{devel_name}
The zlib-devel package contains the header files and libraries needed
to develop programs that use the zlib compression and decompression
library.

Install the zlib-devel package if you want to develop applications that
will use the zlib library.

%package -n	%{static_name}
Summary:	Static libraries for developing apps which will use zlib
Group:		Development/C
Requires:	%{devel_name} = %{version}-%{release}
Provides:	%{name}-static-devel = %{version}-%{release}
Conflicts:	%{devel_name} < 1.2.11-9

%description -n	%{static_name}
The zlib-static-devel package contains the static libraries needed
to develop programs that use the zlib compression and decompression
library.

Install the zlib-static-devel package if you want to develop applications that
will use the zlib library statically.

%if %{with minizip}
%package -n	%{libminizip}
Summary:	Minizip manipulates files from a .zip archive
Group:		System/Libraries

%description -n	%{libminizip}
Minizip manipulates files from a .zip archive.

%package -n	%{minizip_devel}
Summary:	Development files for the minizip library
Group:		Development/C
Requires:	%{libminizip} = %{version}-%{release}
Requires:	zlib-devel = %{version}-%{release}
Provides:	libminizip-devel = %{version}-%{release}
Provides:	minizip-devel = %{version}-%{release}

%description -n	%{minizip_devel}
This package contains the libraries and header files needed for
developing applications which use minizip.
%endif

%prep
%setup -q
%autopatch -p1

%build
#(peroyvind): be sure to remove -m64/-m32 flags as they're not overridable
RPM_OPT_FLAGS="`echo $RPM_OPT_FLAGS| sed -e 's/-m.. //g'` -O3"
mkdir objs
cp -a $(ls | grep -v objs) objs/
pushd objs
  CFLAGS="$RPM_OPT_FLAGS" LDFLAGS="%{?ldflags}" \
  ./configure --shared --prefix=%{_prefix} --libdir=%{_libdir}
  %make_build
  make test
popd

%if %{with minizip}
pushd contrib/minizip
autoreconf --install
%configure --enable-static=no
%make_build
popd
%endif


%if %{with dietlibc}
mkdir objsdietlibc
cp -a $(ls | grep -v objs) objsdietlibc/
pushd objsdietlibc
  CFLAGS="-Os" CC="diet gcc" \
  ./configure --prefix=%{_prefix}
  %make_build libz.a
popd
%endif


%install
install -d %{buildroot}%{_prefix}
install -d %{buildroot}%{_libdir}

make install -C objs prefix=%{buildroot}%{_prefix} libdir=%{buildroot}%{_libdir}

%if %{with minizip}
pushd contrib/minizip
%make_install
popd
%endif

%if %{with dietlibc}
install -m644 objsdietlibc/libz.a -D %{buildroot}%{_prefix}/lib/dietlibc/lib-%{_arch}/libz.a
%endif

%if %{with minizip}
rm -fr %{buildroot}%{_libdir}/libminizip.la
# https://bugzilla.redhat.com/show_bug.cgi?id=1424609
# https://github.com/madler/zlib/pull/229
rm -fr %{buildroot}%{_includedir}/minizip/crypt.h
%endif

%files -n %{lib_name}
%doc README
%{_libdir}/libz.so.%{lib_major}{,.*}

%files -n %{devel_name}
%doc README ChangeLog doc/algorithm.txt
%{_mandir}/man3/zlib.3*
%{_libdir}/libz.so
%{_libdir}/pkgconfig/zlib.pc
%{_includedir}/zconf.h
%{_includedir}/zlib.h

%files -n %{static_name}
%{_libdir}/libz.a
%if %{with dietlibc}
%{_prefix}/lib/dietlibc/lib-%{_arch}/libz.a
%endif

%if %{with minizip}
%files -n %{libminizip}
%{_libdir}/libminizip.so.%{lib_major}{,.*}

%files -n %{minizip_devel}
%{_libdir}/pkgconfig/minizip.pc
%{_libdir}/libminizip.so
%{_includedir}/minizip/
%endif


%changelog
* Fri Nov 03 2023 ns80 <ns80> 1.2.13-1.1.mga9
+ Revision: 2003784
- add upstream patch for CVE-2023-45853 (mga#32426)

* Fri Oct 14 2022 luigiwalser <luigiwalser> 1.2.13-1.mga9
+ Revision: 1896833
- 1.2.13
- remove upstream patches

* Mon Aug 29 2022 ns80 <ns80> 1.2.12-4.mga9
+ Revision: 1881633
- add upstream patch to fix a regression introduced by the fix for CVE-2022-37434 (mga#30715)

* Mon Aug 08 2022 neoclust <neoclust> 1.2.12-3.mga9
+ Revision: 1876218
- Add P100: Fixes CVE-2022-37434 (mga#30715)

* Sat Apr 16 2022 tmb <tmb> 1.2.12-2.mga9
+ Revision: 1850583
- Correct incorrect inputs provided to the CRC functions

* Tue Mar 29 2022 ns80 <ns80> 1.2.12-1.mga9
+ Revision: 1831853
- new version 1.2.12

* Thu Mar 24 2022 tmb <tmb> 1.2.11-12.mga9
+ Revision: 1825296
- Fix a bug that can crash deflate on some input when using Z_FIXED (mga#30204)

* Wed Mar 16 2022 umeabot <umeabot> 1.2.11-11.mga9
+ Revision: 1794882
- Mageia 9 Mass Rebuild

* Mon May 03 2021 daviddavid <daviddavid> 1.2.11-10.mga9
+ Revision: 1720986
- add back uncompress2 function (mga#28839)

* Sun Mar 08 2020 wally <wally> 1.2.11-9.mga8
+ Revision: 1554871
- split out static devel pkg

* Fri Feb 14 2020 umeabot <umeabot> 1.2.11-8.mga8
+ Revision: 1519149
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sun Sep 23 2018 umeabot <umeabot> 7.mga7-current
+ Revision: 1302060
- Mageia 7 Mass Rebuild

* Wed May 02 2018 daviddavid <daviddavid> 1.2.11-6.mga7
+ Revision: 1224461
- do not install crypt.h minizip header (rhbz#1424609)
  * looks like we get a breakage in sigil due that

* Fri Feb 09 2018 tmb <tmb> 1.2.11-5.mga7
+ Revision: 1199928
- sync with MGAA-2017-0125 from mga6

* Wed Mar 29 2017 neoclust <neoclust> 1.2.11-4.mga6
+ Revision: 1095154
- Add more conflicts

* Wed Mar 29 2017 neoclust <neoclust> 1.2.11-3.mga6
+ Revision: 1095142
- Add conflict to ease upgrade from mga5(mga#20562)

* Mon Feb 06 2017 zezinho <zezinho> 1.2.11-2.mga6
+ Revision: 1085045
- remove biarch build to allow simultaneous install of i586 and x86_64 versions

* Mon Jan 16 2017 luigiwalser <luigiwalser> 1.2.11-1.mga6
+ Revision: 1082005
- 1.2.11
- remove patch changing internal version (not needed)

* Mon Jan 09 2017 luigiwalser <luigiwalser> 1.2.10-3.mga6
+ Revision: 1080779
- revert addition of uncompress2 function in 1.2.9

* Mon Jan 09 2017 luigiwalser <luigiwalser> 1.2.10-2.mga6
+ Revision: 1080775
- change internal version to 1.2.9.1 to work around buggy maven

* Tue Jan 03 2017 luigiwalser <luigiwalser> 1.2.10-1.mga6
+ Revision: 1079972
- remove upstreamed patches and update URLs
- 1.2.10

* Tue Oct 04 2016 luigiwalser <luigiwalser> 1.2.8-10.mga6
+ Revision: 1058600
- add upstream patches to fix issues found by mozilla security audit

* Sun Jan 17 2016 daviddavid <daviddavid> 1.2.8-9.mga6
+ Revision: 925180
- switch to %%configure2_5x to fix build

* Fri Aug 21 2015 tmb <tmb> 1.2.8-8.mga6
+ Revision: 867778
- rebuild for new gcc

* Wed Oct 15 2014 umeabot <umeabot> 1.2.8-7.mga5
+ Revision: 747129
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1.2.8-6.mga5
+ Revision: 730757
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 1.2.8-5.mga5
+ Revision: 690882
- Mageia 5 Mass Rebuild

* Wed Aug 20 2014 tv <tv> 1.2.8-4.mga5
+ Revision: 665832
- drop uclibc build

* Mon Dec 16 2013 boklm <boklm> 1.2.8-3.mga4
+ Revision: 557186
- Rebuild for new uclibc

* Sat Oct 19 2013 umeabot <umeabot> 1.2.8-2.mga4
+ Revision: 532944
- Mageia 4 Mass Rebuild

* Mon Jul 08 2013 luigiwalser <luigiwalser> 1.2.8-1.mga4
+ Revision: 451058
- 1.2.8

* Mon Jan 14 2013 umeabot <umeabot> 1.2.7-7.mga3
+ Revision: 387754
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Sep 17 2012 fwang <fwang> 1.2.7-6.mga3
+ Revision: 294833
- bump rel

* Mon Sep 17 2012 fwang <fwang> 1.2.7-5.mga3
+ Revision: 294829
- setarch merged into util-linux

* Sat Jul 21 2012 colin <colin> 1.2.7-4.mga3
+ Revision: 273158
- Update for usrmove

* Sat Jul 07 2012 dmorgan <dmorgan> 1.2.7-3.mga3
+ Revision: 268555
- Build minizip

* Tue May 29 2012 shlomif <shlomif> 1.2.7-1.mga3
+ Revision: 248898
- New version: 1.2.7

* Mon Jan 30 2012 fwang <fwang> 1.2.6-1.mga2
+ Revision: 203353
- new version 1.2.6

* Fri Oct 28 2011 tmb <tmb> 1.2.5-5.mga2
+ Revision: 159068
- split out uClibc-zlib(-devel) in separate rpms so basesystem-minimal
  does not require uClibc anymore.
- drop buildroot and defattr

* Sat Jan 08 2011 blino <blino> 1.2.5-3.mga1
+ Revision: 448
- imported package zlib


* Fri Dec 17 2010 Funda Wang <fwang@mandriva.org> 1.2.5-3mdv2011.0
+ Revision: 622614
- add gentoo patch to fix building of downstream packages
- use own own ldflags

  + Per Øyvind Karlsen <peroyvind@mandriva.org>
    - remove scriptlets for long dead releases

* Tue Nov 30 2010 Funda Wang <fwang@mandriva.org> 1.2.5-2mdv2011.0
+ Revision: 603298
- obsoletes old package name

* Mon Nov 29 2010 Per Øyvind Karlsen <peroyvind@mandriva.org> 1.2.5-1mdv2011.0
+ Revision: 603123
- don't lower zlib's default compile optimization level, compile with -O3
- add versioned build dependency on clibc to ensure getting working one..
- add new pkgconfig files to %%files
- fix new path to algorithm.txt
- fix multibuild patch
- new release: 1.2.5
- drop obsolete patches fixed upstream
- ditch feeble attempt at multilib...

  + Emmanuel Andry <eandry@mandriva.org>
    - apply library policy

* Wed Jan 06 2010 Per Øyvind Karlsen <peroyvind@mandriva.org> 1.2.3-15mdv2010.1
+ Revision: 486696
- build shared version of uclibc linked library as well, obsoleting uClibc-zlib
- use %%{uclibc_cflags} for uclibc gcc flags
- add back dietlibc build
- don't create symlinks to headers for uClibc, it's not really required...
- don't build uclibc linked library with debugging information

* Tue Dec 01 2009 Per Øyvind Karlsen <peroyvind@mandriva.org> 1.2.3-14mdv2010.1
+ Revision: 472167
- don't split out uclibc linked zlib after all, do multiarch build in stead
- install header symlinks for uclibc
- split uclibc linked static library into a separate package
- replace dietlibc build with uclibc as dietlibc seems pretty much abandoned...

* Tue Dec 16 2008 Oden Eriksson <oeriksson@mandriva.com> 1.2.3-13mdv2009.1
+ Revision: 314890
- rediffed one fuzzy patch

* Thu Aug 07 2008 Thierry Vignaud <tv@mandriva.org> 1.2.3-12mdv2009.0
+ Revision: 266170
- rebuild early 2009.0 package (before pixel changes)

* Tue Jun 10 2008 Oden Eriksson <oeriksson@mandriva.com> 1.2.3-11mdv2009.0
+ Revision: 217581
- rebuilt against dietlibc-devel-0.32

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Tue May 20 2008 Oden Eriksson <oeriksson@mandriva.com> 1.2.3-10mdv2009.0
+ Revision: 209452
- rebuilt with gcc43

* Tue Mar 04 2008 Oden Eriksson <oeriksson@mandriva.com> 1.2.3-9mdv2008.1
+ Revision: 178766
- rebuild

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Wed Aug 15 2007 Olivier Blin <oblin@mandriva.com> 1.2.3-8mdv2008.0
+ Revision: 63510
- build dietlibc library with -Os (better, and fix weird segfault)

* Mon Aug 13 2007 Olivier Blin <oblin@mandriva.com> 1.2.3-7mdv2008.0
+ Revision: 62821
- move diet libz in _prefix/lib/dietlibc/lib-_arch (to follow gb's convention)

  + Per Øyvind Karlsen <peroyvind@mandriva.org>
    - install static dietlibc library in correct place on sparc
    - package is now sparcv9 in stead of sparc64 on on sparc
    - be sure to set 64 bit environment also at link time as compiler on sparc
      defaults to 32 bit


* Thu Jan 25 2007 Olivier Blin <oblin@mandriva.com> 1.2.3-5mdv2007.0
+ Revision: 113526
- build a diet libz-diet.a archive

* Mon Dec 04 2006 Gwenole Beauchesne <gbeauchesne@mandriva.com> 1.2.3-4mdv2007.1
+ Revision: 90324
- fix bi-arch builds with different -m32/-m64 optflags

  + Oden Eriksson <oeriksson@mandriva.com>
    - bzip2 cleanup

* Thu Oct 12 2006 Oden Eriksson <oeriksson@mandriva.com> 1.2.3-3mdv2007.1
+ Revision: 63458
- bunzip patches
- Import zlib

* Wed Oct 05 2005 Gwenole Beauchesne <gbeauchesne@mandriva.com> 1.2.3-2mdk
- make it a biarch package on ppc64

* Fri Jul 22 2005 Nicolas Lécureuil <neoclust@mandriva.org> 1.2.3-1mdk
- New release 1.2.3
- Drop patch 5 ( Merged Upstream )

* Thu Jul 21 2005 Olivier Blin <oblin@mandriva.com> 1.2.2.2-3mdk
- from Vincent Danen: security fix for CAN-2005-2096

* Thu Jan 20 2005 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 1.2.2.2-2mdk
- make sure we are compiling DSO with -fPIC in configure tests

* Thu Jan 13 2005 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 1.2.2.2-1mdk
- 1.2.2.2
- drop packager tag

* Thu Dec 02 2004 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 1.2.2.1-1mdk
- 1.2.2.1

* Sat Aug 28 2004 Frederic Lepied <flepied@mandrakesoft.com> 1.2.1.1-3mdk
- fix from Debian

* Tue Jul 13 2004 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 1.2.1.1-2mdk
- change default compile flags only for 32 bits build when building on sparc64

* Sun May 30 2004 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 1.2.1.1-1mdk
- 1.2.1.1
- spec cosmetics

